==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QImageEncoderControl_shell.h <==
#ifndef QIMAGEENCODERCONTROL_SHELL_H
#define QIMAGEENCODERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qimageencodercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaencodersettings.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QImageEncoderControl_shell : public QImageEncoderControl, public QtJambiShellInterface
{
public:
    QImageEncoderControl_shell(QObject* parent0 = nullptr);
    ~QImageEncoderControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString imageCodecDescription(const QString& codec0) const override;
    QImageEncoderSettings imageSettings() const override;
    void setImageSettings(const QImageEncoderSettings& settings0) override;
    QStringList supportedImageCodecs() const override;
    QList<QSize> supportedResolutions(const QImageEncoderSettings& settings0, bool* continuous1) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QImageEncoderControl_access : public QImageEncoderControl
{
    jstring __qt_imageCodecDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring codec0) const;
    jobject __qt_imageSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setImageSettings_cref_QImageEncoderSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0);
    jobject __qt_supportedImageCodecs(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_supportedResolutions_cref_QImageEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
};

#endif // QIMAGEENCODERCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QImageEncoderControl_shell.h <==
#ifndef QIMAGEENCODERCONTROL_SHELL_H
#define QIMAGEENCODERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qimageencodercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaencodersettings.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QImageEncoderControl_shell : public QImageEncoderControl, public QtJambiShellInterface
{
public:
    QImageEncoderControl_shell(QObject* parent0 = nullptr);
    ~QImageEncoderControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString imageCodecDescription(const QString& codec0) const override;
    QImageEncoderSettings imageSettings() const override;
    void setImageSettings(const QImageEncoderSettings& settings0) override;
    QStringList supportedImageCodecs() const override;
    QList<QSize> supportedResolutions(const QImageEncoderSettings& settings0, bool* continuous1) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QImageEncoderControl_access : public QImageEncoderControl
{
    jstring __qt_imageCodecDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring codec0) const;
    jobject __qt_imageSettings_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setImageSettings_cref_QImageEncoderSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0);
    jobject __qt_supportedImageCodecs_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_supportedResolutions_cref_QImageEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
};

#endif // QIMAGEENCODERCONTROL_SHELL_H
